photoshop package
=================

Subpackages
-----------

.. toctree::

   photoshop.colors
   photoshop.save_options

Submodules
----------

photoshop.action\_descriptor module
-----------------------------------

.. automodule:: photoshop.action_descriptor
   :members:
   :undoc-members:
   :show-inheritance:

photoshop.action\_list module
-----------------------------

.. automodule:: photoshop.action_list
   :members:
   :undoc-members:
   :show-inheritance:

photoshop.action\_refrence module
---------------------------------

.. automodule:: photoshop.action_refrence
   :members:
   :undoc-members:
   :show-inheritance:

photoshop.active\_document module
---------------------------------

.. automodule:: photoshop.active_document
   :members:
   :undoc-members:
   :show-inheritance:

photoshop.active\_layer module
------------------------------

.. automodule:: photoshop.active_layer
   :members:
   :undoc-members:
   :show-inheritance:

photoshop.application module
----------------------------

.. automodule:: photoshop.application
   :members:
   :undoc-members:
   :show-inheritance:

photoshop.artlayer module
-------------------------

.. automodule:: photoshop.artlayer
   :members:
   :undoc-members:
   :show-inheritance:

photoshop.artlayers module
--------------------------

.. automodule:: photoshop.artlayers
   :members:
   :undoc-members:
   :show-inheritance:

photoshop.constants module
--------------------------

.. automodule:: photoshop.constants
   :members:
   :undoc-members:
   :show-inheritance:

photoshop.document module
-------------------------

.. automodule:: photoshop.document
   :members:
   :undoc-members:
   :show-inheritance:

photoshop.documents module
--------------------------

.. automodule:: photoshop.documents
   :members:
   :undoc-members:
   :show-inheritance:

photoshop.enumerations module
-----------------------------

.. automodule:: photoshop.enumerations
   :members:
   :undoc-members:
   :show-inheritance:

photoshop.errors module
-----------------------

.. automodule:: photoshop.errors
   :members:
   :undoc-members:
   :show-inheritance:

photoshop.layer module
----------------------

.. automodule:: photoshop.layer
   :members:
   :undoc-members:
   :show-inheritance:

photoshop.layerSet module
-------------------------

.. automodule:: photoshop.layerSet
   :members:
   :undoc-members:
   :show-inheritance:

photoshop.layerSets module
--------------------------

.. automodule:: photoshop.layerSets
   :members:
   :undoc-members:
   :show-inheritance:

photoshop.layers module
-----------------------

.. automodule:: photoshop.layers
   :members:
   :undoc-members:
   :show-inheritance:

photoshop.preferences module
----------------------------

.. automodule:: photoshop.preferences
   :members:
   :undoc-members:
   :show-inheritance:

photoshop.selection module
--------------------------

.. automodule:: photoshop.selection
   :members:
   :undoc-members:
   :show-inheritance:

photoshop.solid\_color module
-----------------------------

.. automodule:: photoshop.solid_color
   :members:
   :undoc-members:
   :show-inheritance:

photoshop.text\_fonts module
----------------------------

.. automodule:: photoshop.text_fonts
   :members:
   :undoc-members:
   :show-inheritance:

photoshop.text\_item module
---------------------------

.. automodule:: photoshop.text_item
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: photoshop
   :members:
   :undoc-members:
   :show-inheritance:
